BezierCircuitPrimitive

Qualified name: algan.rendering.primitives.bezier\_circuit\_primitive.BezierCircuitPrimitive

class BezierCircuitPrimitive(corners=None, next_segment_inds=None, num_segments_per_circuit=None, colors=Color([0.3451, 0.7686, 0.8667, 0.0000, 1.0000]), opacity=1, normals=None, stroke_width=None, stroke_color=None, mob_center=None, grid_width=None, grid_height=None, first_basis=None, second_basis=None, triangle_collection=None, glow=0, num_texture_points=0, filled=True, num_pixels_per_sample=0.5, z_index=None)[source]

Bases: RenderPrimitive

Methods

batch_identifier_for

get_batch_identifier

Key used by the scene batcher: primitives with equal keys are merged into one batched primitive of this class.

Attributes

frame_dependent_source_attrs

get_batch_identifier()[source]

Key used by the scene batcher: primitives with equal keys are merged into one batched primitive of this class.